==> owncloud-9.1.4.tgz: owncloud/lib/l10n/km.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "today" : "ថ្ងៃនេះ",
    "yesterday" : "ម្សិលមិញ",
    "last month" : "ខែមុន",
    "_%n month ago_::_%n months ago_" : ["%n ខែ​មុន"],
    "last year" : "ឆ្នាំ​មុន",
    "_%n hour ago_::_%n hours ago_" : ["%n ម៉ោង​មុន"],
    "_%n minute ago_::_%n minutes ago_" : ["%n នាទី​មុន"],
    "seconds ago" : "វិនាទី​មុន",
    "App directory already exists" : "មាន​ទីតាំង​ផ្ទុក​កម្មវិធី​រួច​ហើយ",
    "Can't create app folder. Please fix permissions. %s" : "មិន​អាច​បង្កើត​ថត​កម្មវិធី។ សូម​កែ​សម្រួល​សិទ្ធិ។ %s",
    "%s enter the database username." : "%s វាយ​បញ្ចូល​ឈ្មោះ​អ្នក​ប្រើ​មូលដ្ឋាន​ទិន្នន័យ។",
    "%s enter the database name." : "%s វាយ​បញ្ចូល​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ។",
    "%s you may not use dots in the database name" : "%s អ្នក​អាច​មិន​ប្រើ​សញ្ញា​ចុច​នៅ​ក្នុង​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ",
    "Oracle connection could not be established" : "មិន​អាច​បង្កើត​ការ​តភ្ជាប់ Oracle",
    "DB Error: \"%s\"" : "កំហុស DB៖ \"%s\"",
    "PostgreSQL username and/or password not valid" : "ឈ្មោះ​អ្នក​ប្រើ និង/ឬ ពាក្យ​សម្ងាត់ PostgreSQL គឺ​មិន​ត្រូវ​ទេ",
    "Set an admin username." : "កំណត់​ឈ្មោះ​អ្នក​គ្រប់គ្រង។",
    "Set an admin password." : "កំណត់​ពាក្យ​សម្ងាត់​អ្នក​គ្រប់គ្រង។",
    "Could not find category \"%s\"" : "រក​មិន​ឃើញ​ចំណាត់​ក្រុម \"%s\"",
    "Apps" : "កម្មវិធី",
    "A valid username must be provided" : "ត្រូវ​ផ្ដល់​ឈ្មោះ​អ្នក​ប្រើ​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "Help" : "ជំនួយ",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Users" : "អ្នកប្រើ",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "No app name specified" : "មិន​បាន​បញ្ជាក់​ឈ្មោះ​កម្មវិធី",
    "web services under your control" : "សេវាកម្ម​វេប​ក្រោម​ការ​ការ​បញ្ជា​របស់​អ្នក",
    "Application is not enabled" : "មិន​បាន​បើក​កម្មវិធី",
    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.3.tgz: owncloud/lib/l10n/km.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "today" : "ថ្ងៃនេះ",
    "yesterday" : "ម្សិលមិញ",
    "last month" : "ខែមុន",
    "_%n month ago_::_%n months ago_" : ["%n ខែ​មុន"],
    "last year" : "ឆ្នាំ​មុន",
    "_%n hour ago_::_%n hours ago_" : ["%n ម៉ោង​មុន"],
    "_%n minute ago_::_%n minutes ago_" : ["%n នាទី​មុន"],
    "seconds ago" : "វិនាទី​មុន",
    "None" : "គ្មាន",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Password" : "ពាក្យសម្ងាត់",
    "App directory already exists" : "មាន​ទីតាំង​ផ្ទុក​កម្មវិធី​រួច​ហើយ",
    "Can't create app folder. Please fix permissions. %s" : "មិន​អាច​បង្កើត​ថត​កម្មវិធី។ សូម​កែ​សម្រួល​សិទ្ធិ។ %s",
    "Apps" : "កម្មវិធី",
    "General" : "ទូទៅ",
    "Storage" : "ឃ្លាំង​ផ្ទុក",
    "Security" : "សុវត្ថិភាព",
    "Encryption" : "កូដនីយកម្ម",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Search" : "ស្វែង​រក",
    "%s enter the database username." : "%s វាយ​បញ្ចូល​ឈ្មោះ​អ្នក​ប្រើ​មូលដ្ឋាន​ទិន្នន័យ។",
    "%s enter the database name." : "%s វាយ​បញ្ចូល​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ។",
    "%s you may not use dots in the database name" : "%s អ្នក​អាច​មិន​ប្រើ​សញ្ញា​ចុច​នៅ​ក្នុង​ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ",
    "Oracle connection could not be established" : "មិន​អាច​បង្កើត​ការ​តភ្ជាប់ Oracle",
    "DB Error: \"%s\"" : "កំហុស DB៖ \"%s\"",
    "PostgreSQL username and/or password not valid" : "ឈ្មោះ​អ្នក​ប្រើ និង/ឬ ពាក្យ​សម្ងាត់ PostgreSQL គឺ​មិន​ត្រូវ​ទេ",
    "Set an admin username." : "កំណត់​ឈ្មោះ​អ្នក​គ្រប់គ្រង។",
    "Set an admin password." : "កំណត់​ពាក្យ​សម្ងាត់​អ្នក​គ្រប់គ្រង។",
    "Could not find category \"%s\"" : "រក​មិន​ឃើញ​ចំណាត់​ក្រុម \"%s\"",
    "A valid username must be provided" : "ត្រូវ​ផ្ដល់​ឈ្មោះ​អ្នក​ប្រើ​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "A valid password must be provided" : "ត្រូវ​ផ្ដល់​ពាក្យ​សម្ងាត់​ឲ្យ​បាន​ត្រឹម​ត្រូវ",
    "Help" : "ជំនួយ",
    "Settings" : "ការកំណត់",
    "Users" : "អ្នកប្រើ",
    "web services under your control" : "សេវាកម្ម​វេប​ក្រោម​ការ​ការ​បញ្ជា​របស់​អ្នក",
    "Application is not enabled" : "មិន​បាន​បើក​កម្មវិធី",
    "Authentication error" : "កំហុស​ការ​ផ្ទៀង​ផ្ទាត់​ភាព​ត្រឹម​ត្រូវ",
    "Unknown user" : "មិនស្គាល់អ្នកប្រើប្រាស់"
},
"nplurals=1; plural=0;");
